/*
Copyright (C) 2022 Christoph Boelitz

E-mail: tools@dosforum.de
Project page: http://tools.dosforum.de/

This program is free software as long as its used privately.
Commercial use, as unlikely as it may seem, is hereby prohibited.
The source code may be modified and distributed as long
as my contact information is left in place.

Let me know, if you have suggestions or see something that can
be done in a better way, so I might learn from it. Thanks!
*/

#include "log.h"

FILE* log_file;    //File pointer

int open_logfile(char* filename)
{
  log_file = fopen(filename, "at"); //Open for append

  if (!log_file) log_file = fopen(filename, "wt"); //Create new

  if (log_file == NULL)
    return LOG_ERR_LOGFILE_OPEN;

  return LOG_ERR_SUCCESS;
}

void close_logfile()
{
  fclose(log_file);
}

int textout_log(int err, int log, char* text, ...)
{
  //This is basically a wrapper function, that logs to
  //screen and to file while taking a list of arguments.

  char buf[LOG_BUFFER];

  va_list args;

  va_start(args, text);

  vsprintf(buf, text, args);

  va_end(args);

  //Screen output
  if (err)
    fputs(buf, stderr);
  else
    fputs(buf, stdout);


  if (log)
  {
    //Get current system time and format as string.

    char time_str[30];
    struct tm *time_st;
    time_t now = time(NULL);

    if (now == -1)
      return LOG_ERR_TIME;

    time_st = localtime(&now);
    strftime(time_str, 30, "%b %d %Y; %H:%M:%S", time_st);

    fprintf(log_file, "%s: %s", time_str, buf);
  }

  return LOG_ERR_SUCCESS;
}
